#
# FULLOCK - Fast User Level LOCK library
#
# Copyright 2015 Yahoo Japan Corporation.
#
# FULLOCK is fast locking library on user level by Yahoo! JAPAN.
# FULLOCK is following specifications.
#
# For the full copyright and license information, please view
# the license file that was distributed with this source code.
#
# AUTHOR:   Takeshi Nakatani
# CREATE:   Thu 16 Jul 2015
# REVISION:
#

#
# Local macros/define
#
%if %{undefined package_revision}
%global package_revision 1
%endif

%if %{undefined make_build}
%global make_build %{__make} %{?_smp_mflags}
%endif

%if %{undefined autosetup}
%global autosetup %setup -q
%endif

%global gittag v1.0.59

%if %{undefined make_check}
%global make_check 1
%endif

%if %{undefined not_run_autogen}
%global run_autogen ./autogen.sh
%else
%global run_autogen echo "skip autogen.sh"
%endif

#
# main package
#
Summary: Fast User Level LOCK (FULLOCK) library for C/C++
Name: libfullock
Version: 1.0.59
Release: %{package_revision}%{?dist}
License: MIT

URL: https://github.com/yahoojapan/fullock
Source0: https://github.com/yahoojapan/fullock/archive/%{gittag}/fullock-%{version}.tar.gz
BuildRequires: git-core gcc-c++ make libtool

%description
fullock is an open-source software for user level lock library sup-
ported by Yahoo! JAPAN. It runs on user level and provides two types
lock. One is a shared reader/writer lock which has the same function-
ality with pthread_rwlock. Another is a shared mutex lock which also
has the same functionality with pthread_mutex.

Here is primary fullock features:

1. fullock is a thread safety library which can be used for multi-
processing as well as for multi-threading.

2. fullock releases a mutex lock safely even if a lock owner
process exit with 0 in which case OS doesn't release the lock.

3. fullock provides a shared reader/writer lock. A lock owner
thread can get another lock again without deadlock.

Please visit our website and get more details at:

https://github.com/yahoojapan/fullock

%prep
%autosetup -n fullock-%{version}

%build
%run_autogen
%configure --disable-static 
%make_build

%install
%make_install
find %{buildroot} -name '*.la' -exec rm -f {} ';'
mkdir -p %{buildroot}/var/lib/antpickax

%if %{make_check}
%check
%{__make} check
%endif

%if %{defined ldconfig_scriptlets}
%ldconfig_scriptlets
%else
%post -p /sbin/ldconfig
%postun -p /sbin/ldconfig
%endif

%if 0%{?rhel} == 6
%clean
rm -rf %{buildroot}
%endif

%files
%if 0%{?rhel} == 6
%doc COPYING
%defattr(-,root,root)
%else
%license COPYING
%endif
%doc README AUTHORS ChangeLog
%{_libdir}/libfullock.so.1*
%{_mandir}/man3/*
%dir %attr(0777,root,root) /var/lib/antpickax

#
# devel package
#
%package devel
Summary: Fast User Level LOCK (FULLOCK) library for C/C++ (development)
Requires: %{name}%{?_isa} = %{version}-%{release}

%description devel
Development package for building with libfullock shared library.
This package has header files and symbols for it.

%files devel
%if 0%{?rhel} == 6
%defattr(-,root,root)
%endif
%doc README AUTHORS ChangeLog
%{_includedir}/*
%{_libdir}/libfullock.so
%{_libdir}/pkgconfig/*.pc

%changelog
* Fri Mar 08 2024 Takeshi Nakatani <ggtakec@gmail.com> 1.0.59-1
- Fixed Makefile.am about cppcheck version - #115

* Thu Mar 07 2024 Takeshi Nakatani <ggtakec@gmail.com> 1.0.58
- Updated docker/login-action from v2 to v3 - #113
- Fixed cppcheck error and Makefile.am - #111
- Changed support OS (fedora and alpine) - #110

* Thu Nov 16 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.57
- Fixed build_helper.sh for ruby 2.7 required package_cloud - #108

* Thu Nov 16 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.56
- Fixed a bug in build_helper.sh - #105

* Fri Oct 27 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.55
- Fixed build_helper.sh for upgrading ruby required package_cloud - #103

* Thu Oct 26 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.54
- Changed support OS (fedora and ubuntu) - #101

* Fri Aug 25 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.53
- Fixed a bug about packaging - #99

* Fri Aug 25 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.52
- Updated tool scripts and support OSs - #97

* Tue Jun 20 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.51
- Fixed .gitignore to exclude APKBUILD.templ - #95

* Tue Feb 28 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.50
- Updated build helper scripts on CI process - #93

* Mon Feb 27 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.49
- Updated building/packaging logic for ALPINE - #91

* Wed Feb 08 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.48
- Fixed package dependency and docker image for ALPINE - #89

* Mon Feb 06 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.47
- Fixed package dependency for ALPINE package - #87

* Fri Feb 03 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.46
- Fixed bugs in build_helper.sh and imagetypevars.sh - #85

* Thu Feb 02 2023 Takeshi Nakatani <ggtakec@gmail.com> 1.0.45
- Fixed a bug about publishing in build_helper.sh - #83
- Supported fedora 37 and dropped support for fedora 35dropped - #81
- Changed CI process flow/OSs and added Alpine OS - #80
- Fixed a bug in rule.in file for debian packaging - #79
- Added gcc -fno-lto option - #78
- [gh-pages] Updated header and footer in comment lines - #77
- Updated header and footer in comment lines - #76
- Updated issue/pullrequest templates - #75
- Updated Makefile.am about cppcheck - #74
- Updated Makefile.am about cppcheck - #73
- Added ShellCheck processing and reviewed cppcheck - #72
- Fixed a bug in build_helper.sh - #71
- Eliminated unnecessary copies in build_helper.sh - #70
- Updated docker/login-action from v1 to v2 - #69
- Fixed a bug in docker_helper.sh and ci.yml - #68
- Shared Docker image build logic with other products - #67
- Re-updated github actions process(3) - #66
- Re-updated github actions process(2) - #65
- Re-updated github actions process - #64
- Updated github actions process and support os, and fixed bugs - #63
- Updated debian_build.sh for changing grep parameter - #62
- Updated common build scripts - #61
- Updated Antpickax common scripts and tools under the buildutils directory - #60
- Fixed errors reported by cppcheck 2.9 - #59
- Updated .gitignore Makefile.am configure.ac - #58
- Fixed build error on CentOS8 - #57
- Fixed configure.ac for making dist archive - #56
- Fixed code for cppcheck 2.7 error - #55
- Enabled external customization of variables in configure.ac - #54

* Fri Aug 27 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.44
- Fixed Dockerfile template for calling ldconfig - #52

* Tue Aug 17 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.43
- Fixed a bug in Docker image build - #50

* Fri Aug 13 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.42
- Fixed to create /var/lib/antpickax at installation - #48

* Tue Aug 10 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.41
- Fixed a bug in Dockerfile.templ.in and updated .gitignore - #46

* Fri Aug 06 2021 Takeshi Nakatani <ggtakec@gmail.com> 1.0.40
- Fixed ci.yml for Docker image build/push - #45
- Added docker build and push in Github Actions - #43
- Functional improvements and bug fixes - #42

* Wed Dec 16 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.39
- Fixed centos8 build and removed centos6 build - #38

* Mon Nov 16 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.38
- Fixed a bug in build_helper.sh - #36

* Fri Nov 13 2020 Takeshi Nakatani <ggtakec@gmail.com> 1.0.37
- Switched Travis CI to Github actions and extended supported OS - #34
- Fixed bugs detected by cppcheck - #33
- Fixes typos. - #32

* Mon Mar 11 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.36
- Fixed codes for cppcheck 1.87 - #29

* Thu Jan 17 2019 Takeshi Nakatani <ggtakec@gmail.com> 1.0.35
- Fixed misspelling, and etc - #26
- Added check using cppcheck - #25
- Changed method name from IsLowRobust to IsRobust - #24
- Reflected the spelling check result for all sources - #23
- Fixed Typo and Comment - #22

* Fri Dec 28 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.34
- some small fix(typo and optimize code) - #15

* Tue Dec 11 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.33
- Updated common build tool files

* Tue Dec 04 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.32
- Fixed RPM packaging about configure.ac and spec file
- Updated some scripts related to packaging

* Tue Nov 27 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.31
- Changed to strict packaging and changed documents

* Wed Oct 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.30
- Fixed lintian error in man page about wrong word(2)

* Wed Oct 17 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.29
- Fixed lintian error in man page about wrong word

* Fri Jun 29 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.28
- avoid static object initialization order problem(SIOF) - #4

* Tue May 15 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.27
- Updated make description script for packaging
- Fixed a bug about packaging for debian

* Tue May 15 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.26
- Fixed a bug about packaging for debian

* Tue May 15 2018 Takeshi Nakatani <ggtakec@gmail.com> 1.0.25
- Cleanup credit comments in sources
- Changed build logic to new for rpm/debian packaging
- Updated the man page

* Mon Mar 13 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.24
- Added lib_version_for_link option to make_valiables.sh
- Refixed a bug about deadlock at forking - #1

* Mon Feb 13 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.23
- Fixed a bug about deadlock at forking

* Mon Feb 06 2017 Takeshi Nakatani <ggtakec@gmail.com> 1.0.22
- Changed exclusive control more strictly

* Wed Dec 07 2016 Takeshi Nakatani <ggtakec@gmail.com> 1.0.21
- First version of open source on Github
